==> apache-shardingsphere-5.5.2-src.zip: apache-shardingsphere-5.5.2-src-release/kernel/data-pipeline/core/src/test/java/org/apache/shardingsphere/data/pipeline/core/job/progress/JobItemIncrementalTasksProgressTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.data.pipeline.core.job.progress;

import org.apache.shardingsphere.data.pipeline.core.task.progress.IncrementalTaskProgress;
import org.junit.jupiter.api.Test;

import static org.hamcrest.CoreMatchers.is;
import static org.hamcrest.MatcherAssert.assertThat;
import static org.junit.jupiter.api.Assertions.assertFalse;
import static org.junit.jupiter.api.Assertions.assertTrue;
import static org.mockito.Mockito.RETURNS_DEEP_STUBS;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;

class JobItemIncrementalTasksProgressTest {
    
    @Test
    void assertGetIncrementalPositionWithNullIncrementalTaskProgress() {
        assertFalse(new JobItemIncrementalTasksProgress(null).getIncrementalPosition().isPresent());
    }
    
    @Test
    void assertGetIncrementalPositionWithNotNullIncrementalTaskProgress() {
        assertTrue(new JobItemIncrementalTasksProgress(mock(IncrementalTaskProgress.class, RETURNS_DEEP_STUBS)).getIncrementalPosition().isPresent());
    }
    
    @Test
    void assertGetIncrementalLatestActiveTimeMillisWithNullIncrementalTaskProgress() {
        assertThat(new JobItemIncrementalTasksProgress(null).getIncrementalLatestActiveTimeMillis(), is(0L));
    }
    
    @Test
    void assertGetIncrementalLatestActiveTimeMillisWithNotNullIncrementalTaskProgress() {
        IncrementalTaskProgress incrementalTaskProgress = mock(IncrementalTaskProgress.class, RETURNS_DEEP_STUBS);
        when(incrementalTaskProgress.getIncrementalTaskDelay().getLatestActiveTimeMillis()).thenReturn(10L);
        assertThat(new JobItemIncrementalTasksProgress(incrementalTaskProgress).getIncrementalLatestActiveTimeMillis(), is(10L));
    }
}

==> apache-shardingsphere-5.5.3-src.zip: apache-shardingsphere-5.5.3-src-release/kernel/data-pipeline/core/src/test/java/org/apache/shardingsphere/data/pipeline/core/job/progress/JobItemIncrementalTasksProgressTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.data.pipeline.core.job.progress;

import org.apache.shardingsphere.data.pipeline.core.task.progress.IncrementalTaskProgress;
import org.junit.jupiter.api.Test;

import static org.hamcrest.Matchers.is;
import static org.hamcrest.MatcherAssert.assertThat;
import static org.junit.jupiter.api.Assertions.assertFalse;
import static org.junit.jupiter.api.Assertions.assertTrue;
import static org.mockito.Mockito.RETURNS_DEEP_STUBS;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;

class JobItemIncrementalTasksProgressTest {
    
    @Test
    void assertGetIncrementalPositionWithNullIncrementalTaskProgress() {
        assertFalse(new JobItemIncrementalTasksProgress(null).getIncrementalPosition().isPresent());
    }
    
    @Test
    void assertGetIncrementalPositionWithNotNullIncrementalTaskProgress() {
        assertTrue(new JobItemIncrementalTasksProgress(mock(IncrementalTaskProgress.class, RETURNS_DEEP_STUBS)).getIncrementalPosition().isPresent());
    }
    
    @Test
    void assertGetIncrementalLatestActiveTimeMillisWithNullIncrementalTaskProgress() {
        assertThat(new JobItemIncrementalTasksProgress(null).getIncrementalLatestActiveTimeMillis(), is(0L));
    }
    
    @Test
    void assertGetIncrementalLatestActiveTimeMillisWithNotNullIncrementalTaskProgress() {
        IncrementalTaskProgress incrementalTaskProgress = mock(IncrementalTaskProgress.class, RETURNS_DEEP_STUBS);
        when(incrementalTaskProgress.getIncrementalTaskDelay().getLatestActiveTimeMillis()).thenReturn(10L);
        assertThat(new JobItemIncrementalTasksProgress(incrementalTaskProgress).getIncrementalLatestActiveTimeMillis(), is(10L));
    }
}
